==> vokoscreen-ng_3.0.5.orig.tar.gz: vokoscreenNG-3.0.5/src/language/eu_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="eu_ES" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Hautatu gailu bat edo gehiago</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Aldatu leihora</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Aldatu pantaila osora</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Atzera-kontua</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Hautatu gailu bat edo gehiago</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Laguntza</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Abisua</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Grabazioa ez da hasi, ez dago nahikoa tokirik diskoan.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Diskoaren espazio librea bukatu da.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Diskoaren espazio librearen muga</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Grabazioa gelditu da, ez dago espazio libre nahikorik.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantaila osoa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Leihoa</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ez da fitxategi arakatzailerik aurkitu</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instalatu fitxategi arakatzaile bat.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Mahaigaineko saioa Wayland saioa da</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Wayland oraindik ez da onartzen. Pantaila-grabazioak pantaila beltza erakusten du. Amaitu saioa eta hasi X11 mahaigaineko saioa</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Iturburu-kodea</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hasiera-orria</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Itzulpenak</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Dohaintza egin</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland mahaigaineko saioa hauteman da</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Ireki fitxategia</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Eremua</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Hasi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jarraitu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>irten</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Hasi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jarraitu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Irten</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Elkarrizketa</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Irauli horizontalean</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Irauli bertikalean</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Alderantzizkatu</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grisa</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zuri-beltza</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Kendu leihoaren markoa</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameraren ezarpenak</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Eremua</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Berrezarri</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Atzera-kontua</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Bideoaren tamaina:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Diskoko leku librea:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informazioa</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Grabazio denbora:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audioa</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramak</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Bideo-kodeka</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatua</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audio-kodeka</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kalitatea</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ez grabatu saguaren erakuslea</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Ordu</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minutu</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Abiatu tenporizadorea</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Gelditu grabazioa denbora honen ondoren</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ordu</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutu</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundo</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Bideoaren bidea</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Diskoaren espazio librearen muga</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Erakutsi erretiluan</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundo hauen ondoren hasi grabatzen</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Begiratu eguneraketak</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Laguntza</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Bideoa</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Eskuragarria</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ez eskuragarria</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Hasi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jarraitu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Erreproduzitu</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Karpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Alderantzizkatu</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grisa</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Bidali txostena</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+MAIUS+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+MAIUS+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+MAIUS+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Erreproduzitu grabatutako azkena</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ireki karpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+MAIUS+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizatu grabazioa hastean</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Abiatu minimizatuta</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Irauli horizontalean</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Irauli bertikalean</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zuri-beltza</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Kendu leihoaren markoa</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Dohaintza egin</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Leheneratu ezarpen guztiak abiatzen den hurrengoan</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Irudien gaineko copyrighta eta lizentzia</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Pantaila-grabazioa</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Erreproduzigailua</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Erregistroa</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Irudien gaineko copyrighta eta lizentzia</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Erreproduzitu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Ireki fitxategia</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantaila osoa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Aurreko fotograma</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Hurrengo fotograma</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mutu</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mugitu menua</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/eu_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="eu_ES" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Hautatu gailu bat edo gehiago</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Aldatu leihora</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Aldatu pantaila osora</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Atzera-kontua</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Hautatu gailu bat edo gehiago</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Laguntza</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Abisua</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Grabazioa ez da hasi, ez dago nahikoa tokirik diskoan.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Diskoaren espazio librea bukatu da.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Diskoaren espazio librearen muga</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Grabazioa gelditu da, ez dago espazio libre nahikorik.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantaila osoa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Leihoa</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ez da fitxategi arakatzailerik aurkitu</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instalatu fitxategi arakatzaile bat.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Mahaigaineko saioa Wayland saioa da</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Wayland oraindik ez da onartzen. Pantaila-grabazioak pantaila beltza erakusten du. Amaitu saioa eta hasi X11 mahaigaineko saioa</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Iturburu-kodea</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hasiera-orria</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Itzulpenak</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Eman dirua</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland mahaigaineko saioa hauteman da</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Ireki fitxategia</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Eremua</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Hasi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jarraitu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>irten</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Hasi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jarraitu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Irten</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Elkarrizketa</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Irauli horizontalean</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Irauli bertikalean</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Alderantzizkatu</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grisa</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zuri-beltza</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Kendu leihoaren markoa</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameraren ezarpenak</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Eremua</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Berrezarri</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Atzera-kontua</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Bideoaren tamaina:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Diskoko leku librea:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informazioa</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Grabazio denbora:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audioa</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramak</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Bideo-kodeka</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatua</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audio-kodeka</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kalitatea</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ez grabatu saguaren erakuslea</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Ordu</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minutu</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Abiatu tenporizadorea</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Gelditu grabazioa denbora honen ondoren</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ordu</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutu</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundo</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Bideoaren bidea</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Diskoaren espazio librearen muga</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Erakutsi erretiluan</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundo hauen ondoren hasi grabatzen</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Begiratu eguneraketak</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Laguntza</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Bideoa</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Eskuragarria</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ez eskuragarria</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Hasi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jarraitu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Erreproduzitu</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Karpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Alderantzizkatu</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grisa</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Bidali txostena</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+MAIUS+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+MAIUS+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+MAIUS+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Erreproduzitu grabatutako azkena</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ireki karpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+MAIUS+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizatu grabazioa hastean</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Abiatu minimizatuta</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Irauli horizontalean</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Irauli bertikalean</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zuri-beltza</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Kendu leihoaren markoa</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Eman dirua</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Leheneratu ezarpen guztiak abiatzen den hurrengoan</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Irudien gaineko copyrighta eta lizentzia</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Pantaila-grabazioa</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Erreproduzigailua</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Erregistroa</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Irudien gaineko copyrighta eta lizentzia</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Erreproduzitu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Ireki fitxategia</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantaila osoa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Aurreko fotograma</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Hurrengo fotograma</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mutu</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mugitu menua</translation>
    </message>
</context>
</TS>
